import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:senior_design_system/senior_design_system.dart';
import 'package:senior_platform_authentication/senior_platform_authentication.dart';

import '../../core/authentication/presentation/bloc/authentication_bloc.dart';
import '../../core/l10n/l10n_extension.dart';
import '../../core/widgets/base_authentication_screen.dart';
import 'cubit/mfa_authentication_code_cubit.dart';
import 'widgets/mfa_authentication_content.dart';

class MFAAuthenticationScreen extends StatelessWidget {
  final MFAInfo mfaInfo;

  const MFAAuthenticationScreen({
    super.key,
    required this.mfaInfo,
  });

  @override
  Widget build(BuildContext context) {
    return BaseAuthenticationScreen(
      child: BlocProvider<MFAAuthenticationCubit>(
        create: (context) => MFAAuthenticationCubit(
          sendMfaConfigEmailUsecase: SendMFAConfigEmailUsecase(),
          loginMFAUsecase: LoginMFAUsecase(),
          authenticationBloc: context.read<AuthenticationBloc>(),
        )..initialize(mfaInfo),
        child: SeniorBackdrop(
          onTapBack: () {
            Navigator.pop(context);
          },
          title: Builder(
              builder: (context) => Text(
                    context.l10n.authentication_code,
                  )),
          body: const MFAAuthenticationContent(),
        ),
      ),
    );
  }
}
