import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:font_awesome_flutter/font_awesome_flutter.dart';
import 'package:senior_design_system/senior_design_system.dart';
import 'package:senior_design_tokens/senior_design_tokens.dart';
import 'package:senior_platform_authentication/senior_platform_authentication.dart';

import '../../core/authentication/presentation/bloc/authentication_bloc.dart';
import '../../core/l10n/l10n_extension.dart';
import '../../core/widgets/base_authentication_screen.dart';
import 'cubit/username_authentication_cubit.dart';
import 'widgets/username_authentication_content.dart';

class UserNameAuthenticationScreen extends StatelessWidget {
  const UserNameAuthenticationScreen({super.key});

  @override
  Widget build(BuildContext context) {
    return BaseAuthenticationScreen(
      child: BlocProvider<UserNameAuthenticationCubit>(
        create: (context) => UserNameAuthenticationCubit(
          getTenantLoginSettingsUsecase: GetTenantLoginSettingsUsecase(),
          loginUsecase: LoginUsecase(),
          authenticationBloc: context.read<AuthenticationBloc>(),
        ),
        child: SeniorBackdrop(
          hideLeading: true,
          actions: [
            IconButton(
              icon: const FaIcon(
                FontAwesomeIcons.solidCircleQuestion,
                size: SeniorSpacing.normal,
              ),
              onPressed: () {},
            )
          ],
          title: Builder(
              builder: (context) => SeniorText.label(
                    context.l10n.userNameScreenTitle,
                    color: SeniorColors.pureWhite,
                  )),
          body: const UserNameAuthenticationContent(),
        ),
      ),
    );
  }
}
