import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:senior_design_system/senior_design_system.dart';
import 'package:senior_design_tokens/senior_design_tokens.dart';

import '../../../../senior_platform_authentication_ui.dart';
import '../../../core/l10n/l10n_extension.dart';
import '../../mfa_authentication/mfa_authentication_screen.dart';
import '../../saml_authentication/saml_authentication_screen.dart';
import 'username_authentication_form.dart';

class UserNameAuthenticationContent extends StatelessWidget {
  const UserNameAuthenticationContent({
    super.key,
  });

  @override
  Widget build(BuildContext context) {
    return Padding(
      padding: const EdgeInsets.all(SeniorSpacing.normal),
      child: BlocListener<UserNameAuthenticationCubit,
          UserNameAuthenticationState>(
        listenWhen: (previous, current) =>
            (previous.errorType != current.errorType) ||
            (previous.authenticationFlow != current.authenticationFlow),
        listener: (context, state) {
          if (state.errorType != null && state.status == NetworkStatus.idle) {
            ScaffoldMessenger.of(context)
              ..hideCurrentSnackBar()
              ..showSnackBar(
                SeniorSnackBar.error(
                  message: _getSnackbarErrorMessage(context, state.errorType!),
                  action: SeniorSnackBarAction(
                    label: context.l10n.ok,
                    onPressed: () =>
                        ScaffoldMessenger.of(context).hideCurrentSnackBar(),
                  ),
                ),
              );
          }

          if (state.authenticationFlow == AuthenticationFlow.saml) {
            Navigator.push(
              context,
              MaterialPageRoute(
                builder: (_) => SAMLAuthenticationScreen(
                  username: state.username,
                  tenantDomain: state.tenantLoginSettings?.tenantDomain ?? '',
                ),
              ),
            );
          }
          if (state.authenticationFlow == AuthenticationFlow.mfa) {
            Navigator.push(
              context,
              MaterialPageRoute(
                builder: (_) => MFAAuthenticationScreen(
                  mfaInfo: state.mfaInfo!,
                ),
              ),
            );
          }
        },
        child: const CustomScrollView(
          slivers: [
            SliverFillRemaining(
              hasScrollBody: false,
              child: UserNameAuthenticationForm(),
            ),
          ],
        ),
      ),
    );
  }

  String _getSnackbarErrorMessage(BuildContext context, ErrorType errorType) {
    if (errorType == ErrorType.tenantNotFound) {
      return context.l10n.tenant_not_found_error_message;
    }

    if (errorType == ErrorType.unauthorized) {
      return context.l10n.unauthorized_error_message;
    }

    return context.l10n.generic_error_message;
  }
}
